# Generated by Django 5.0.4 on 2024-04-22 20:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('artd_urls', '0002_alter_url_partner_alter_urlconfiguration_partner'),
    ]

    operations = [
        migrations.RenameField(
            model_name='url',
            old_name='decorator',
            new_name='decorators',
        ),
    ]
