# Generated by Django 5.0.4 on 2024-04-22 20:42

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
        ('artd_urls', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='url',
            name='partner',
            field=models.OneToOneField(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner'),
        ),
        migrations.AlterField(
            model_name='urlconfiguration',
            name='partner',
            field=models.OneToOneField(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner'),
        ),
    ]
