# Generated by Django 5.0.4 on 2024-04-22 20:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Url',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, verbose_name='status')),
                ('url', models.CharField(blank=True, help_text='Enter the url of the product', max_length=250, null=True, verbose_name='Url')),
                ('module', models.CharField(blank=True, help_text='Enter the module of the product', max_length=250, null=True, verbose_name='Module')),
                ('name', models.CharField(blank=True, help_text='Enter the name of the product', max_length=250, null=True, verbose_name='Name')),
                ('decorator', models.CharField(blank=True, help_text='Enter the decorator of the product', max_length=250, null=True, verbose_name='Decorator')),
                ('partner', models.ForeignKey(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner')),
            ],
            options={
                'verbose_name': 'Url',
                'verbose_name_plural': 'Urls',
            },
        ),
        migrations.CreateModel(
            name='UrlConfiguration',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, verbose_name='status')),
                ('include_admin_urls', models.BooleanField(default=True, help_text='Include the admin urls in the list', verbose_name='Include Admin URLs')),
                ('include_dinamic_urls', models.BooleanField(default=True, help_text='Include the dinamic urls in the list', verbose_name='Include Dinamic URLs')),
                ('partner', models.ForeignKey(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner')),
            ],
            options={
                'verbose_name': 'Url Configuration',
                'verbose_name_plural': 'Url Configurations',
            },
        ),
    ]
